@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/MahJong/newmj/RCS/sysdep.c,v 12.2 2012/02/01 15:29:02 jcb Rel $
+/* $Header: /home/jcb/MahJong/newmj/RCS/sysdep.c,v 12.4 2020/05/30 17:37:37 jcb Exp $
  * sysdep.c
  * By intention, this file contains all functions that might need
  * fiddling with to cope with different variants of Unix.
@@ -21,10 +21,11 @@
  *                                                           *
  *************************************************************/
 
-static const char rcs_id[] = "$Header: /home/jcb/MahJong/newmj/RCS/sysdep.c,v 12.2 2012/02/01 15:29:02 jcb Rel $";
-
 #include "sysdep.h"
 #include <string.h>
+
+static const char rcs_id[] UNUSED = "$Header: /home/jcb/MahJong/newmj/RCS/sysdep.c,v 12.4 2020/05/30 17:37:37 jcb Exp $";
+
 /* This is missing in my windows mingw */
 #ifdef WIN32
 char *index(const char *s, int c) {
@@ -650,7 +651,11 @@ int put_data(SOCKET fd, char *data, int len) {
   
   if ( len == 0 ) {
 #   ifdef WIN32
+#   ifdef XCOMPILE
+    n = shutdown(fd, SHUT_WR);
+#   else
     n = shutdown(fd, SD_SEND);
+#   endif
 #   else
     n = shutdown(fd, SHUT_WR);
 #   endif
@@ -957,8 +962,9 @@ int unlink(const char *f) {
 
 unsigned int sleep(unsigned int t) { Sleep(1000*t); return 0; }
 
+#ifndef XCOMPILE
 /* I don't think we really need submillisecond resolution ... */
 unsigned int usleep(unsigned int t) { Sleep(t/1000); return 0; }
-
+#endif
 
 #endif /* WIN32 */
